#!/bin/bash

function showUsage {
  echo "Usage: $(basename $0) [command]"
  echo "Run a specific command."
  echo "  restart      Restart radmin service (does not enable it)"
  echo "  enable       Enable radmin service (does not start it)"
  echo "  disable      Disable radmin service (does not stop it)"
  echo "  stop         Stop radmin service (does not disable it)"
  echo "  status       Return connection status to server (exit with 0 if connected, 1 otherwise)"
  exit 1
}

if [ $# -lt 1 ]
then
  showUsage
  exit 1
fi


COMMAND=$1
SRV=`cat /etc/radmin/config.json | jq -r .server`
PORT=`cat /etc/radmin/config.json | jq -r .sshPort`
if [ "$SRV" = "" ]
then
  SRV="radmin.ipconnect.fr"
fi

case $COMMAND in
  restart)
    systemctl restart radmin
  ;;
  enable)
    systemctl enable radmin
  ;;
  disable)
    systemctl disable radmin
  ;;
  stop)
    systemctl stop radmin
  ;;
  status)
    IP=`dig $SRV +short`
    CONNECTED=`ss -n | grep $IP:$PORT | grep ESTAB | wc -l`
    if [ "$CONNECTED" = "1" ]
    then
      echo "Radmin is connected to $IP:$PORT"
      exit 0
    else
      echo "Radmin is not connected"
      exit 1
    fi
  ;;
  *)
    echo "Unknown command $COMMAND"
    echo ""
    showUsage
  ;;
esac

exit 0